async fn validate_node_map<TYPES: NodeType>(
node_map: &NodeMapSanitized<TYPES>,
) -> Result<()>Expand description
For a NodeMapSanitized, we validate that each leaf extends the preceding leaf.
async fn validate_node_map<TYPES: NodeType>(
node_map: &NodeMapSanitized<TYPES>,
) -> Result<()>For a NodeMapSanitized, we validate that each leaf extends the preceding leaf.